@@ -17,10 +17,15 @@ test_that("Consensus() errors", {
   expect_equal(Consensus(c(halfTree)), halfTree)
   expect_equal(Consensus(list(halfTree)), halfTree)
   
+  # Test that trees larger than heap limit fail gracefully
   expect_error(
-    Consensus(c(BalancedTree(33333), PectinateTree(33333))),
-    "too many leaves"
+    Consensus(c(BalancedTree(100001), PectinateTree(100001))),
+    "too many leaves.*100000"
   )
+  
+  largeTree <- BalancedTree(33333)
+  consensus_large <- Consensus(c(largeTree, largeTree))
+  expect_equal(NTip(consensus_large), 33333)
 })
 
 test_that("Consensus()", {
@@ -65,6 +70,9 @@ test_that("Consensus() handles large sets of trees", {
     oneTree
   )
   
+  skip_on_cran() # Slow!
+  skip_if(!isTRUE(options("runSlowTests")))
+  
   expect_true(all.equal(
     Consensus(manyTrees),
     read.tree(text = "((((((t2,t13),t12),t11),t10),t3,t4,t5,t6,t7,t8,t9),t1);")
